Versioning Scheme
======================

Versions should follow the `Pep 0440 Versioning Scheme <https://peps.python.org/pep-0440/#version-scheme>`__

**MAJOR.MINOR.BUGFIX**

Example: ``2.0.1``

Defined as:

* **MAJOR** should be incremented for API breaking changes

* **MINOR** should be incremented for additions

* **BUGFIX** should be incremented for bugfixes


* If releasing an Alpha Release then **a#** should be appended to end of release ie ``2.0.1a1``

* If releasing an Beta Release then **a#** should be appended to end of release ie ``2.0.1b1``

* If releasing a Release Candidate then **rc#** should be appended to end of release ie ``2.0.1rc2``

.. note::

    For minor fixes a **post#** can be appended. See `Post Releases <https://peps.python.org/pep-0440/#post-releases>`__ for more information

